@@ -9,7 +9,6 @@ from .asserts import (  # noqa
 from .exceptions import ImproperlyConfigured  # noqa
 from .expressions import Asterisk, row_to_json  # noqa
 from .functions import (  # noqa
-    analyze,
     cast_if,
     create_database,
     create_mock_engine,
@@ -37,6 +36,7 @@ from .functions import (  # noqa
     identity,
     is_loaded,
     json_sql,
+    jsonb_sql,
     merge_references,
     mock_engine,
     naturally_equivalent,
@@ -71,6 +71,8 @@ from .types import (  # noqa
     DateTimeRangeType,
     EmailType,
     EncryptedType,
+    EnrichedDateTimeType,
+    EnrichedDateType,
     instrumented_list,
     InstrumentedList,
     Int8RangeType,
@@ -101,4 +103,4 @@ from .view import (  # noqa
     refresh_materialized_view
 )
 
-__version__ = '0.35.0'
+__version__ = '0.36.8'
